---
hide:
  - navigation
---

# Examples


## Instructions

1. Log in to your databricks workspace
2. Run any cluster with no isolation shared or single user cluster with unity catalog.
3. Clone the repo into the workspace or import specific notebooks
4. Run the notebook end to end and click the url. Make sure you click the databricks url and not
`localhost`, `0.0.0.0` or `10.x.x.x` urls.

## Examples Repo

[![GitHub](https://img.shields.io/badge/GitHub-dbtunnel--examples-brightgreen?style=flat&logo=github)](https://github.com/stikkireddy/dbtunnel-examples){:target="_blank"}


## Examples 

1. fastapi ✅
2. gradio ✅
3. stable diffusion webui ✅
4. streamlit ✅
5. flask ✅
6. dash ✅
7. bokeh ✅
8. shiny for python ✅
9. solara ✅
10. chainlit ✅
11. code-server on repos ✅
